Graphical FrontEnd
=====================

.. automodule:: datadigitizer.gui
    :members:

Icon
=======

.. automodule:: datadigitizer.icon
    :members:

Settings
============

.. automodule:: datadigitizer.settings
    :members:

Tests
===========

.. automodule:: datadigitizer.tests
    :members: